@@ -5,8 +5,7 @@ Class and standalone app for Independent Component Analysis
 import argparse
 from numpy import random, sqrt, zeros, real, dot, outer, diag, transpose
 from scipy.linalg import sqrtm, inv, orth
-from pyspark import SparkContext
-from thunder.utils import load
+from thunder.utils import ThunderContext
 from thunder.utils import save
 from thunder.factorization import SVD
 from thunder.utils.matrices import RowMatrix
@@ -144,9 +143,9 @@ if __name__ == "__main__":
 
     args = parser.parse_args()
     
-    sc = SparkContext(appName="ica")
+    tsc = ThunderContext.start(appName="ica")
 
-    data = load(sc, args.datafile, args.preprocess).cache()
+    data = tsc.loadText(args.datafile, args.preprocess).cache()
     result = ICA(args.k, args.c, args.svdmethod, args.maxiter, args.tol, args.seed).fit(data)
 
     outputdir = args.outputdir + "-ica"
